==> http_response_headers-3.0.5.tar.gz: http_response_headers/src/Controller/ResponseHeaderListBuilder.php <==
<?php

namespace Drupal\http_response_headers\Controller;

use Drupal\Core\Config\Entity\ConfigEntityListBuilder;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Render\Markup;

/**
 * Provides a listing of Response Headers.
 */
class ResponseHeaderListBuilder extends ConfigEntityListBuilder {

  /**
   * {@inheritdoc}
   */
  public function buildHeader() {
    $header['label'] = $this->t('Label');
    $header['description'] = $this->t('Description');
    $header['name'] = $this->t('Name');
    $header['value'] = $this->t('Value');
    $header['conditions'] = $this->t('Conditions');
    $header['status'] = $this->t('Status');
    return $header + parent::buildHeader();
  }

  /**
   * {@inheritdoc}
   */
  public function buildRow(EntityInterface $entity) {
    $row['label'] = $entity->label();
    $row['description'] = Markup::create('<em class="http-response-headers-description">' . $entity->get('description') . '</em>');
    $row['name'] = $entity->get('name');
    $row['value'] = ($value = $entity->get('value')) ? mb_strimwidth($value, 0, 50, '...') : ' - ';
    $row['conditions'] = Markup::create('<span class="marker">' . (empty($entity->get('visibility')) ? $this->t('Site-wide') : $this->t('Restricted')) . '</span>');
    $row['status'] = $entity->get('status') ?
      Markup::create('<span class="marker marker--published">' . $this->t('Active') . '</span>')
      : Markup::create('<span class="marker">' . $this->t('Disabled') . '</span>');
    return $row + parent::buildRow($entity);
  }

  /**
   * {@inheritdoc}
   */
  public function render() {
    $build = parent::render();
    if (!empty($build['table']['#rows'])) {
      $build['table']['#attributes']['class'][] = 'http-response-headers-list views-field';
    }
    return $build;
  }

}

==> http_response_headers-3.0.7.tar.gz: http_response_headers/src/Controller/ResponseHeaderListBuilder.php <==
<?php

namespace Drupal\http_response_headers\Controller;

use Drupal\Core\Config\Entity\ConfigEntityListBuilder;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Render\Markup;

/**
 * Provides a listing of Response Headers.
 */
class ResponseHeaderListBuilder extends ConfigEntityListBuilder {

  /**
   * {@inheritdoc}
   */
  public function buildHeader() {
    $header['label'] = $this->t('Label');
    $header['description'] = $this->t('Description');
    $header['name'] = $this->t('Name');
    $header['value'] = $this->t('Value');
    $header['conditions'] = $this->t('Conditions');
    $header['status'] = $this->t('Status');
    return $header + parent::buildHeader();
  }

  /**
   * {@inheritdoc}
   */
  public function buildRow(EntityInterface $entity) {
    $row['label'] = $entity->label();
    $row['description'] = Markup::create('<em class="http-response-headers-description">' . $entity->get('description') . '</em>');
    $row['name'] = $entity->get('name');
    $row['value'] = ($value = $entity->get('value')) ? mb_strimwidth($value, 0, 50, '...') : ' - ';
    $row['conditions'] = Markup::create('<span class="marker">' . (empty($entity->get('visibility')) ? $this->t('Sitewide') : $this->t('Restricted')) . '</span>');
    $row['status'] = $entity->get('status') ?
      Markup::create('<span class="marker marker--published">' . $this->t('Active') . '</span>')
      : Markup::create('<span class="marker">' . $this->t('Disabled') . '</span>');
    return $row + parent::buildRow($entity);
  }

  /**
   * {@inheritdoc}
   */
  public function render() {
    $build = parent::render();
    if (!empty($build['table']['#rows'])) {
      $build['table']['#attributes']['class'][] = 'http-response-headers-list views-field';
    }
    return $build;
  }

}
